@@ -76,8 +76,7 @@ sub write_with_flags {
 		$flow->[0],
 		$flow->[1],
 		IPPROTO_TCP,
-		$timestamp
-	));
+	), $timestamp );
 }
 
 sub write {
